@@ -134,6 +134,11 @@
 /*	Available in Postfix 3.7 and later:
 /* .IP "\fBheader_from_format (standard)\fR"
 /*	The format of the Postfix-generated \fBFrom:\fR header.
+/* .PP
+/*	Available in Postfix 3.10 and later:
+/* .IP "\fBtls_required_enable (yes)\fR"
+/*	Enable support for the "TLS-Required: no" message header, defined
+/*	in RFC 8689.
 /* FILES
 /*	/var/spool/postfix/bounce/* non-delivery records
 /*	/var/spool/postfix/defer/* non-delivery records
@@ -191,6 +196,7 @@
 #include <rcpt_buf.h>
 #include <dsb_scan.h>
 #include <hfrom_format.h>
+#include <sendopts.h>
 
 /* Single-threaded server skeleton. */
 
@@ -363,6 +369,11 @@ static int bounce_notify_proto(char *service_name, VSTREAM *client,
     if (flags & BOUNCE_FLAG_CLEAN)
 	bounce_cleanup_register(service_name, STR(queue_id));
 
+    /*
+     * Do not enforce the REQUIRETLS verb for bounce messages.
+     */
+    sendopts &= ~SOPT_REQUIRETLS_ESMTP;
+
     /*
      * Execute the request.
      */
@@ -431,6 +442,11 @@ static int bounce_verp_proto(char *service_name, VSTREAM *client)
     if (flags & BOUNCE_FLAG_CLEAN)
 	bounce_cleanup_register(service_name, STR(queue_id));
 
+    /*
+     * Do not enforce the REQUIRETLS verb for bounce messages.
+     */
+    sendopts &= ~SOPT_REQUIRETLS_ESMTP;
+
     /*
      * Execute the request. Fall back to traditional notification if a bounce
      * was returned as undeliverable, because we don't want to VERPify those.
@@ -523,6 +539,11 @@ static int bounce_one_proto(char *service_name, VSTREAM *client)
 		 rcpt_buf->dsn_notify, STR(dsn_buf->status),
 		 STR(dsn_buf->action), STR(dsn_buf->reason));
 
+    /*
+     * Do not enforce the REQUIRETLS verb for bounce messages.
+     */
+    sendopts &= ~SOPT_REQUIRETLS_ESMTP;
+
     /*
      * Execute the request.
      */
