@@ -96,6 +96,7 @@
 /*	New York, NY 10011, USA
 /*
 /*	Wietse Venema
+/*	porcupine.org
 /*--*/
 
 /* System library. */
@@ -139,6 +140,7 @@
 #include <split_addr.h>
 #include <dsn_mask.h>
 #include <rec_attr_map.h>
+#include <sendopts.h>
 
 /* Client stubs. */
 
@@ -180,7 +182,7 @@ static QMGR_MESSAGE *qmgr_message_create(const char *queue_name,
     message->sender = 0;
     message->dsn_envid = 0;
     message->dsn_ret = 0;
-    message->smtputf8 = 0;
+    message->sendopts = 0;
     message->filter_xport = 0;
     message->inspect_xport = 0;
     message->redirect_addr = 0;
@@ -550,7 +552,7 @@ static int qmgr_message_read(QMGR_MESSAGE *message)
 				 &message->data_size, &message->data_offset,
 				    &nrcpt, &message->rflags,
 				    &message->cont_length,
-				    &message->smtputf8)) >= 3) {
+				    &message->sendopts)) >= 3) {
 		    /* Postfix >= 1.0 (a.k.a. 20010228). */
 		    if (message->data_offset <= 0 || message->data_size <= 0) {
 			msg_warn("%s: invalid size record: %.100s",
@@ -564,6 +566,8 @@ static int qmgr_message_read(QMGR_MESSAGE *message)
 			rec_type = REC_TYPE_ERROR;
 			break;
 		    }
+		    /* Forward compatibility. */
+		    message->sendopts &= SOPT_FLAG_ALL;
 		} else if (count == 1) {
 		    /* Postfix < 1.0 (a.k.a. 20010228). */
 		    qmgr_message_oldstyle_scan(message);
@@ -794,6 +798,15 @@ static int qmgr_message_read(QMGR_MESSAGE *message)
 	myfree(orig_rcpt);
     }
 
+    /*
+     * If the sender requested REQUIRETLS, don't bounce full messages. This
+     * is better enforced here than in delivery agents and bounce service
+     * daemons.
+     */
+    if (var_requiretls_enable
+	&& (message->sendopts & SOPT_REQUIRETLS_ESMTP))
+	message->dsn_ret = DSN_RET_HDRS;
+
     /*
      * After sending a "delayed" warning, request sender notification when
      * message delivery is completed. While "mail delayed" notifications are
@@ -1150,9 +1163,7 @@ static void qmgr_message_resolve(QMGR_MESSAGE *message)
 	 */
 	if (*var_defer_xports && (message->qflags & QMGR_FLUSH_DFXP) == 0) {
 	    if (defer_xport_argv == 0)
-		defer_xport_argv = argv_split_cw(var_defer_xports,
-						 CHARS_COMMA_SP,
-						 VAR_DEFER_XPORTS);
+		defer_xport_argv = argv_split(var_defer_xports, CHARS_COMMA_SP);
 	    for (cpp = defer_xport_argv->argv; *cpp; cpp++)
 		if (strcmp(*cpp, STR(reply.transport)) == 0)
 		    break;
