@@ -164,7 +164,7 @@
 /*	requirements were not satisfied with any of the servers that
 /*	were tried. The "requiretls" option value is case-insensitive.
 /*
-/*	This feature is available in Postfix 3.10 and later.
+/*	This feature is available in Postfix 3.11 and later.
 /* .IP "\fB-O smtputf8"
 /*	When delivering a message to an SMTP or LMTP server, the server
 /*	must support SMTPUTF8. Try multiple servers if possible, and
@@ -455,8 +455,8 @@
 /* .PP
 /*	Postfix 3.10 and later:
 /* .IP "\fBrequiretls_enable (yes)\fR"
-/*	Enable support for the ESMTP verb "REQUIRETLS", defined in RFC
-/*	8689.
+/*	Enable support for the ESMTP verb "REQUIRETLS" in the "MAIL
+/*	FROM" command.
 /* FILES
 /*	/var/spool/postfix, mail queue
 /*	/etc/postfix, configuration files
@@ -1293,12 +1293,19 @@ int     main(int argc, char **argv)
 	case 'O':
 	    /* NOOP is used to implement ${requiretls} in pipe(8). */
 	    if (strcasecmp(optarg, "REQUIRETLS") == 0) {
-		sm_sendopts |= SOPT_REQUIRETLS_ESMTP;
-	    if (var_requiretls_enable == 0)
-		msg_warn("'-O requiretls' was requested, but the "
-			 "configuration is 'requiretls_enable = no'");
+		if (var_requiretls_enable)
+		    sm_sendopts |= SOPT_REQUIRETLS_ESMTP;
+		else
+		    msg_warn("'-O %s' was requested, but the "
+			     "configuration is '%s = %s'", optarg,
+			     VAR_REQUIRETLS_ENABLE, CONFIG_BOOL_NO);
 	    } else if (strcasecmp(optarg, "SMTPUTF8") == 0) {
-		sm_sendopts |= SOPT_SMTPUTF8_REQUESTED;
+		if (var_smtputf8_enable)
+		    sm_sendopts |= SOPT_SMTPUTF8_REQUESTED;
+		else
+		    msg_warn("'-O %s' was requested, but the "
+			     "configuration is '%s = %s'", optarg,
+			     VAR_SMTPUTF8_ENABLE, CONFIG_BOOL_NO);
 	    } else if (strcasecmp(optarg, "NOOP") != 0) {
 		msg_warn("bad -O option value: '%s' -- ignored", optarg);
 	    }
